/*****************************************************************************
 *
 *  FileLocator.h                         XMM Science Analysis System (SAS)
 *
 *  (c) 1997 European Space Agency  -  Written by Marco Beijersbergen
 *
 *****************************************************************************/

#ifndef __FileLocator_h
#define __FileLocator_h

#include <string>
#include <list>

// Searches for a file in a data search path

class FileLocator {

  public:

    FileLocator();

    // Construct from a colon-separated list of directories
    // (or optionally any other separation character).
    FileLocator(const std::string& dirList, char separator=':');

    FileLocator(const std::list<std::string>& directories);

    // Add a colon separated list of directories to the search path.
    void add(const std::string& directories, char separator=':');

    void add(const std::list<std::string>& directories);

    // Returns the full path name of a file if found in the search path.
    // The behaviour in case of an error (invalid file name, file not found)
    // depends on generateError/generateWarning. If generateError is true,
	// an error is raised, otherwise if generateWarning is true only a message
    // is generated and the function returns an empty string.
    // If the failMessage is specified, it is included in the error message.
    std::string locate(const std::string& fileName,
					   const std::string& failMessage="",
	bool generateError=true, bool generateWarning=false) const;

    friend std::ostream& operator<<(std::ostream&, const FileLocator&);

  private:

    std::list<std::string> _directories;
};

#endif
