// Copyright 1997 (c) European Space Agency - written by Marco Beijersbergen

#include "Tracer.h"
#include <strstream>

Tracer tracer(cerr);

Tracer::Tracer(std::ostream& os) : _os(os), _verbosity(Silent), _indent(0)
{

  // Determine verbosity level from the environment variable SAS_TRACER
  char *verboseFlag = getenv("SAS_TRACER");
  if (verboseFlag) {
    std::strstream ss;
    ss << verboseFlag << std::ends;
    int i;
    ss >> i;
    if (!ss)
      _verbosity = Verbose;
    else {
      if (i <= 0)
	_verbosity = Silent;
      else if (i == 1)
	_verbosity = Stack;
      else if (i == 2)
        _verbosity = Sparse;
      else
	_verbosity = Verbose;
    }
  }
}

Tracer::~Tracer()
{
  if (!_stack.empty()) {
    _os << "Stack:" << endl;
    for (std::list<std::string>::const_iterator i = _stack.begin();
		i != _stack.end(); ++i)
      _os << (*i) << endl;
  }
}

void Tracer::in(const std::string& mess)
{
   _stack.push_back(indent() + mess);
   if (_verbosity >= Verbose) {
     _os << indent() << mess << endl;
     ++_indent;
   }
}

void Tracer::out()
{
  if (_stack.empty()) {
    _os << "error in Tracer: more out than in"<<endl;
    return;
  }
  if (_verbosity >= Verbose) {
    if (_indent > 0) --_indent;
    else _os << "error in indent" << endl;
    _os << indent() << "done " << _stack.back() << endl;
  }
  _stack.pop_back();
}













