!-----------------------------------------------------------------------------
!
!                       XMM Science Analysis System (SAS)
!                      (c) 1997 - 2010 European Space Agency
!
!-----------------------------------------------------------------------------
!
!   stimetypes.f90 --- basic types need by STime ---
!
!   CHANGE HISTORY:
!       UL, 2001-07-12: 1.0.0: - first version (adapted from STime.h)
!
!   AUTHOR:
!       U. Lammers, Thu Jul 12 15:00:17 MET DST 2001
!
!   REFERENCES:
!       [1]: Software Specification Document for the XMM Science Analysis
!            Subsystem, M. Dahlem et. al.,
!
!   $Header: /data/xmm02/cvsadmin/soc_repos/sas/packages/utils/src/stimetypes.f90,v 1.1 2001/07/12 15:00:01 ulammers Exp $
!
module STimeTypes
use types
    !   time systems
    integer(kind=int32), parameter, public  :: ST_UTC = 0, &
                                               ! Coordinated Universal Time
                                               ST_TAI = 1, &
                                               ! International Atomic Time
                                               ST_TT  = 2
                                               ! Terrestrial Time

    !   time input/output formats
    integer(kind=int32), parameter, public  :: ST_FITS = 0, &
                                            ! "yyyy-mm-dd[Thh:mm:ss[.msec]]"
                                            ! or "dd/mm/yy", e.g.
                                            ! 1997-08-12T23:12:45.1233223
                                               ST_CALENDAR =1
                                            ! "Sun Sep 16 01:03:52[.msec] 1973"


    !   time representations
    integer(kind=int32), parameter, public  :: ST_JD = 0, &
                                               ! Julian Day number
                                               ST_MJD = 1, &
                                               ! Modified Julian Day number
                                               ST_DYN = 2
                                               ! Decimal Year Number

    type STimeHandleT
        sequence
        integer, pointer    :: ptr
    end type

    type JulianDayHandleT
        sequence
        integer, pointer    :: ptr
    end type
end module STimeTypes
